Modules
Functions
Return an atom’s blocker status, e.g. the atom “!cat/pkg” has a weak blocker.
Parse a string into a Blocker.
Return an atom’s category, e.g. the atom “=cat/pkg-1-r2” has a category of “cat”.
Compare two atoms returning -1, 0, or 1 if the first atom is less than, equal to, or greater
than the second atom, respectively.
Return an atom’s CPN, e.g. the atom “=cat/pkg-1-r2” has a CPN of “cat/pkg”.
Return an atom’s CPV, e.g. the atom “=cat/pkg-1-r2” has a CPV of “cat/pkg-1-r2”.
Free an atom.
Return the hash value for an atom.
Determine if two atoms intersect.
Parse a string into an atom using a specific EAPI. Pass NULL for the eapi argument in
order to parse using the latest EAPI with extensions (e.g. support for repo deps).
Return an atom’s package, e.g. the atom “=cat/pkg-1-r2” has a package of “pkg”.
Return an atom’s repo, e.g. the atom “=cat/pkg-1-r2:3/4::repo” has a repo of “repo”.
Return the restriction for an atom.
Determine if a restriction matches an atom.
Return an atom’s revision, e.g. the atom “=cat/pkg-1-r2” has a revision of “2”.
Return an atom’s slot, e.g. the atom “=cat/pkg-1-r2:3” has a slot of “3”.
Return an atom’s slot operator, e.g. the atom “=cat/pkg-1-r2:0=” has an equal slot
operator.
Parse a string into a SlotOperator.
Return the string for an atom.
Return an atom’s subslot, e.g. the atom “=cat/pkg-1-r2:3/4” has a subslot of “4”.
Return an atom’s USE dependencies, e.g. the atom “=cat/pkg-1-r2[a,b,c]” has USE
dependencies of “a, b, c”.
Return an atom’s version, e.g. the atom “=cat/pkg-1-r2” has a version of “1-r2”.
Parse a CPV string into an atom.