Function pkgcraft::atom::pkgcraft_atom_new
source · #[no_mangle]
pub unsafe extern "C" fn pkgcraft_atom_new(
atom: *const c_char,
eapi: *const Eapi
) -> *mut AtomExpand description
Parse a string into an atom using a specific EAPI. Pass NULL for the eapi argument in order to parse using the latest EAPI with extensions (e.g. support for repo deps).
Returns NULL on error.
Safety
The atom argument should be a UTF-8 string while eapi may be NULL to use the default EAPI.