Functions
Compare two versions returning -1, 0, or 1 if the first version is less than, equal to, or greater
than the second version, respectively.
Free a version.
Return the hash value for a version.
Determine if two versions intersect.
Parse a string into a version.
Return a version’s revision, e.g. the version “1-r2” has a revision of “2”.
Return a version’s string value without operator.
Return a version’s string value including the operator if it exists.
Parse a string into a version with an operator.