Enum pkgcraft::dep::Dependency

source ·
pub enum Dependency<T: Ordered> {
    Enabled(T),
    Disabled(T),
    AllOf(SortedSet<Box<Dependency<T>>>),
    AnyOf(OrderedSet<Box<Dependency<T>>>),
    ExactlyOneOf(OrderedSet<Box<Dependency<T>>>),
    AtMostOneOf(OrderedSet<Box<Dependency<T>>>),
    Conditional(UseDep, SortedSet<Box<Dependency<T>>>),
}
Dependency specification variants.

Variants



Enabled(T)

Enabled dependency.



Disabled(T)

Disabled dependency (REQUIRED_USE only).



AllOf(SortedSet<Box<Dependency<T>>>)

All of a given dependency set.



AnyOf(OrderedSet<Box<Dependency<T>>>)

Any of a given dependency set.



ExactlyOneOf(OrderedSet<Box<Dependency<T>>>)

Exactly one of a given dependency set (REQUIRED_USE only).



AtMostOneOf(OrderedSet<Box<Dependency<T>>>)

At most one of a given dependency set (REQUIRED_USE only).



Conditional(UseDep, SortedSet<Box<Dependency<T>>>)

Conditional dependency.

Implementations

source

impl<T: Ordered> Dependency<T>

source

pub fn is_empty(&self) -> bool

source

pub fn len(&self) -> usize

Return the number of Dependency objects a Dependency contains.

source

pub fn iter(&self) -> Iter<'_, T>

source

pub fn iter_flatten(&self) -> IterFlatten<'_, T>

source

pub fn iter_recursive(&self) -> IterRecursive<'_, T>

source

pub fn iter_conditionals(&self) -> IterConditionals<'_, T>

source

pub fn sort(&mut self)

Recursively sort a Dependency.

source

impl Dependency<Dep>

source

pub fn package(s: &str, eapi: &'static Eapi) -> Result<Self>

source

impl Dependency<String>

source

pub fn license(s: &str) -> Result<Self>

source

pub fn properties(s: &str) -> Result<Self>

source

pub fn required_use(s: &str) -> Result<Self>

source

pub fn restrict(s: &str) -> Result<Self>

source

impl Dependency<Uri>

source

pub fn src_uri(s: &str) -> Result<Self>