Get a package dependency’s raw blocker value.
For example, the package dependency “!cat/pkg” has a weak blocker.
Parse a string into a Blocker’s raw value.
Return the string for a Blocker.
Get the category of a package dependency.
For example, the package dependency “=cat/pkg-1-r2” returns “cat”.
Compare two package dependencies returning -1, 0, or 1 if the first is less than, equal to, or
greater than the second, respectively.
Get the category and package of a package dependency.
For example, the package dependency “=cat/pkg-1-r2” returns “cat/pkg”.
Get the category, package, and version of a package dependency.
For example, the package dependency “=cat/pkg-1-r2” returns “cat/pkg-1-r2”.
Free a package dependency.
Return the hash value for a package dependency.
Determine if two package dependencies intersect.
Determine if a package dependency intersects with a Cpv.
Parse a string into a package dependency using a specific EAPI. Pass NULL for the eapi argument
in order to parse using the latest EAPI with extensions (e.g. support for repo deps).
Parse a string into an unversioned package dependency.
Get the package and revision of a package dependency.
For example, the package dependency “=cat/pkg-1-r2” returns “pkg-1”.
Get the package name of a package dependency.
For example, the package dependency “=cat/pkg-1-r2” returns “pkg”.
Get the package, version, and revision of a package dependency.
For example, the package dependency “=cat/pkg-1-r2” returns “pkg-1-r2”.
Get the revision of a package dependency.
For example, the package dependency “=cat/pkg-1-r2” returns “r2”.
Get the version of a package dependency.
For example, the package dependency “=cat/pkg-1-r2” returns “1”.
Get the version and revision of a package dependency.
For example, the package dependency “=cat/pkg-1-r2” returns “1-r2”.
Get the repo of a package dependency.
For example, the package dependency “=cat/pkg-1-r2:3/4::repo” returns “repo”.
Return the restriction for a package dependency.
Determine if a restriction matches a package dependency.
Get the slot of a package dependency.
For example, the package dependency “=cat/pkg-1-r2:3” returns “3”.
Get a package dependency’s raw slot operator value.
For example, the package dependency “=cat/pkg-1-r2:0=” has an equal slot operator.
Parse a string into a SlotOperator’s raw value.
Return the string for a SlotOperator.
Return the string for a package dependency.
Get the subslot of a package dependency.
For example, the package dependency “=cat/pkg-1-r2:3/4” returns “4”.
Get the USE dependencies of a package dependency.
For example, the package dependency “=cat/pkg-1-r2[a,b,c]” has USE dependencies of “a, b, c”.
Determine if a string is a valid package dependency.
Get the version of a package dependency.
For example, the package dependency “=cat/pkg-1-r2” returns “1-r2”.
Return a given package dependency without the specified fields.