pkgcraft_dep_modify

Function pkgcraft_dep_modify 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pkgcraft_dep_modify( d: *mut Dep, fields: *mut DepField, values: *mut *mut c_char, len: usize, ) -> *mut Dep
Return a package dependency modifying the specified fields with corresponding string values. Use null pointers for string values to unset a given field.

Returns NULL on error.

Safety

The fields and values arguments must be equal length arrays of DepFields with corresponding string values.