Perform a set operation on two DepSets, assigning to the first.
Determine if a DepSet contains a given DepSpec.
Determine if two DepSets are equal.
Evaluate a DepSet.
Forcibly evaluate a DepSet.
Free a DepSet.
Create a DepSet from an array of DepSpec objects.
Returns the DepSpec element for a given index.
Return the hash value for a DepSet.
Insert a DepSpec into a DepSet.
Return an iterator for a DepSet.
Return a conditionals iterator for a DepSet.
Free a conditionals iterator.
Return the next object from a conditionals iterator.
Return a flatten iterator for a DepSet.
Free a flatten iterator.
Return the next object from a flatten iterator.
Free a DepSet iterator.
Return the next object from a DepSet iterator.
Return the next object from the end of a DepSet iterator.
Return a recursive iterator for a DepSet.
Free a recursive iterator.
Return the next object from a recursive iterator.
Returns true if two DepSets have no elements in common.
Returns true if a DepSet is empty.
Returns true if all the elements of the first DepSet are contained in the second.
Return a DepSet’s length.
Perform a set operation on two DepSets, creating a new set.
Parse a string into a specified DepSet type.
Remove the last value from a DepSet.
Replace a DepSpec with another DepSpec in a DepSet, returning the replaced value.
Replace a DepSpec for a given index in a DepSet, returning the replaced value.
Return the formatted string for a DepSet object.
Compare two DepSpecs returning -1, 0, or 1 if the first is less than, equal to, or greater
than the second, respectively.
Determine if a DepSpec contains a given DepSpec.
Evaluate a DepSpec.
Forcibly evaluate a DepSpec.
Free a DepSpec object.
Return the hash value for a DepSpec.
Return an iterator for a DepSpec.
Return a conditionals iterator for a DepSpec.
Return a flatten iterator for a DepSpec.
Return a recursive iterator for a DepSpec.
Return a DepSpec’s length.
Parse a string into a specified DepSpec type.
Return the formatted string for a DepSpec object.
Get the filename for a Uri.
Free a Uri object.
Return the formatted string for a Uri object.
Get the main URI from a Uri object.