Module eapi

Module eapi 

Functions

pkgcraft_eapi_as_str
Return an EAPI’s identifier.
pkgcraft_eapi_cmp
Compare two Eapi objects chronologically returning -1, 0, or 1 if the first is less than, equal to, or greater than the second, respectively.
pkgcraft_eapi_dep_keys
Return the array of dependency keys for an Eapi.
pkgcraft_eapi_from_str
Get an EAPI from its identifier.
pkgcraft_eapi_has
Check if an EAPI has a feature.
pkgcraft_eapi_hash
Return the hash value for an Eapi.
pkgcraft_eapi_metadata_keys
Return the array of metadata keys for an Eapi.
pkgcraft_eapi_parse
Determine if a string is a valid EAPI.
pkgcraft_eapis
Get all known EAPIS.
pkgcraft_eapis_official
Get all official EAPIS.
pkgcraft_eapis_range
Convert EAPI range into an array of Eapi objects.