pkgcraft_array_free

Function pkgcraft_array_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pkgcraft_array_free( array: *mut *mut c_void, len: usize, )
Free an array without dropping the objects inside it.

Safety

The array objects should be explicitly dropped using other methods otherwise they will leak.