Module pkg

Module pkg 

Modules

ebuild

Enums

PkgFormat

Functions

pkgcraft_pkg_cmp
Compare two packages returning -1, 0, or 1 if the first package is less than, equal to, or greater than the second package, respectively.
pkgcraft_pkg_cpv
Return a package’s CPV.
pkgcraft_pkg_eapi
Return a package’s EAPI.
pkgcraft_pkg_format
Return a package’s format.
pkgcraft_pkg_free
Free an package.
pkgcraft_pkg_hash
Return the hash value for a package.
pkgcraft_pkg_intersects_cpn
Determine if a package intersects with a Cpn.
pkgcraft_pkg_intersects_cpv
Determine if a package intersects with a Cpv.
pkgcraft_pkg_intersects_dep
Determine if a package intersects with a package dependency.
pkgcraft_pkg_repo
Return a package’s repo.
pkgcraft_pkg_restrict
Return the restriction for a package.
pkgcraft_pkg_restrict_matches
Determine if a restriction matches a package.
pkgcraft_pkg_str
Return the string for a package.
pkgcraft_pkg_version
Return a package’s version.