Key

Enum Key 

pub enum Key {
Show 20 variants BDEPEND, DEFINED_PHASES, DEPEND, DESCRIPTION, EAPI, HOMEPAGE, IDEPEND, INHERIT, IUSE, KEYWORDS, LICENSE, PDEPEND, PROPERTIES, RDEPEND, REQUIRED_USE, RESTRICT, SLOT, SRC_URI, INHERITED, CHKSUM,
}
Ebuild package metadata variants.

Many of these directly correspond to variables set in ebuilds or eclasses. See the related metadata key sets in Eapi for EAPI support relating to incrementals, dependencies, and mandatory settings.

Variants



BDEPEND



DEFINED_PHASES



DEPEND



DESCRIPTION



EAPI



HOMEPAGE



IDEPEND



INHERIT



IUSE



KEYWORDS



LICENSE



PDEPEND



PROPERTIES



RDEPEND



REQUIRED_USE



RESTRICT



SLOT



SRC_URI



INHERITED



CHKSUM