pub struct Pkg<'a> { /* private fields */ }Implementations
sourceimpl<'a> Pkg<'a>
impl<'a> Pkg<'a>
sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Return a package’s description.
sourcepub fn properties(&self) -> Option<&DepSet<String>>
pub fn properties(&self) -> Option<&DepSet<String>>
Return a package’s PROPERTIES.
sourcepub fn required_use(&self) -> Option<&DepSet<String>>
pub fn required_use(&self) -> Option<&DepSet<String>>
Return a package’s REQUIRED_USE.
sourcepub fn defined_phases(&self) -> &HashSet<String>
pub fn defined_phases(&self) -> &HashSet<String>
Return a package’s defined phases
sourcepub fn inherit(&self) -> &IndexSet<String>
pub fn inherit(&self) -> &IndexSet<String>
Return the ordered set of directly inherited eclasses for a package.
sourcepub fn inherited(&self) -> &IndexSet<String>
pub fn inherited(&self) -> &IndexSet<String>
Return the ordered set of inherited eclasses for a package.
sourcepub fn maintainers(&self) -> &[Maintainer]
pub fn maintainers(&self) -> &[Maintainer]
Return a package’s maintainers.
sourcepub fn long_description(&self) -> Option<&str>
pub fn long_description(&self) -> Option<&str>
Return a package’s long description.