pub struct EbuildTempRepo { /* private fields */ }Expand description
A temporary repo that is automatically deleted when it goes out of scope.
Implementations
Sourceimpl EbuildTempRepo
impl EbuildTempRepo
pub fn path(&self) -> &Utf8Path
Sourcepub fn create_ebuild<T>(
&mut self,
value: T,
data: &[&str],
) -> Result<Utf8PathBuf>
pub fn create_ebuild<T>( &mut self, value: T, data: &[&str], ) -> Result<Utf8PathBuf>
Create an ebuild using custom data field values.
Sourcepub fn create_ebuild_from_str<T>(
&mut self,
value: T,
data: &str,
) -> Result<Utf8PathBuf>
pub fn create_ebuild_from_str<T>( &mut self, value: T, data: &str, ) -> Result<Utf8PathBuf>
Create an ebuild file in the repo from raw data.
Sourcepub fn create_eclass(&mut self, name: &str, data: &str) -> Result<Utf8PathBuf>
pub fn create_eclass(&mut self, name: &str, data: &str) -> Result<Utf8PathBuf>
Create an eclass in the repo.
Sourcepub fn persist<P: AsRef<Utf8Path>>(self, path: Option<P>) -> Result<Utf8PathBuf>
pub fn persist<P: AsRef<Utf8Path>>(self, path: Option<P>) -> Result<Utf8PathBuf>
Persist the temporary repo to disk, returning the Utf8PathBuf where it is located.