Module restrict

Module restrict 

Functions

pkgcraft_restrict_and
Create a new restriction combining two restrictions via logical AND.
pkgcraft_restrict_eq
Determine if two restrictions are equal.
pkgcraft_restrict_free
Free a restriction.
pkgcraft_restrict_hash
Return the hash value for a restriction.
pkgcraft_restrict_not
Create a new restriction inverting a restriction via logical NOT.
pkgcraft_restrict_or
Create a new restriction combining two restrictions via logical OR.
pkgcraft_restrict_parse_dep
Parse a dependency restriction.
pkgcraft_restrict_parse_pkg
Parse a package query restriction.
pkgcraft_restrict_xor
Create a new restriction combining two restrictions via logical XOR.