Module pkgcraft::traits

source ·

Traits

  • Return true if a container type contains a given object, otherwise false.
  • Iterate over an object’s lines, filtering comments starting with ‘#’ and empty lines returning an enumerated iterator for the remaining content.