Function pkgcraft::atom::pkgcraft_atom_version
source · [−]#[no_mangle]
pub unsafe extern "C" fn pkgcraft_atom_version(
atom: *mut Atom
) -> *const AtomVersionExpand description
Return an atom’s version, e.g. the atom “=cat/pkg-1-r2” has a version of “1-r2”.
Returns NULL on nonexistence.
Safety
The argument must be a non-null Atom pointer. Also, note that the returned pointer is borrowed from its related Atom object and should never be freed manually.