Module version
Source - pkgcraft_revision_cmp⚠
- Compare two revisions returning -1, 0, or 1 if the first is less than, equal to, or greater
than the second, respectively.
- pkgcraft_revision_free⚠
- Free a revision.
- pkgcraft_revision_hash⚠
- Return the hash value for a revision.
- pkgcraft_revision_new⚠
- Parse a string into a revision.
- pkgcraft_revision_str⚠
- Return a revision’s string value.
- pkgcraft_version_base⚠
- Return a version’s base, e.g. the version “1-r2” has a base of “1”.
- pkgcraft_version_cmp⚠
- Compare two versions returning -1, 0, or 1 if the first is less than, equal to, or greater than
the second, respectively.
- pkgcraft_version_free⚠
- Free a version.
- pkgcraft_version_hash⚠
- Return the hash value for a version.
- pkgcraft_version_intersects⚠
- Determine if two versions intersect.
- pkgcraft_version_new⚠
- Parse a string into a version.
- pkgcraft_version_op⚠
- Return a version operator’s raw value.
- pkgcraft_version_op_from_str⚠
- Parse a string into an Operator’s raw value.
- pkgcraft_version_op_str
- Return the string for an Operator.
- pkgcraft_version_parse⚠
- Determine if a string is a valid package version.
- pkgcraft_version_revision⚠
- Return a version’s revision, e.g. the version “1-r2” has a revision of “2”.
- pkgcraft_version_str⚠
- Return a version’s string value without operator.
- pkgcraft_version_with_op⚠
- Potentially create a new Version by applying an operator.