Compare two revisions returning -1, 0, or 1 if the first is less than, equal to, or greater
than the second, respectively.
Free a revision.
Return the hash value for a revision.
Parse a string into a revision.
Return a revision’s string value.
Return a version’s base, e.g. the version “1-r2” has a base of “1”.
Compare two versions returning -1, 0, or 1 if the first is less than, equal to, or greater than
the second, respectively.
Free a version.
Return the hash value for a version.
Determine if two versions intersect.
Parse a string into a version.
Return a version operator’s raw value.
Parse a string into an Operator’s raw value.
Return the string for an Operator.
Return a version’s revision, e.g. the version “1-r2” has a revision of “2”.
Return a version’s string value without operator.
Determine if a string is a valid package version.