Functions
- pkgcraft_
eapi_ ⚠as_ str - Return an EAPI’s identifier.
- pkgcraft_
eapi_ ⚠cmp - Compare two Eapi objects chronologically returning -1, 0, or 1 if the first is less than, equal to, or greater than the second, respectively.
- pkgcraft_
eapi_ ⚠dep_ keys - Return the array of dependency keys for an Eapi.
- pkgcraft_
eapi_ ⚠from_ str - Get an EAPI from its identifier.
- pkgcraft_
eapi_ ⚠has - Check if an EAPI has a feature.
- pkgcraft_
eapi_ ⚠hash - Return the hash value for an Eapi.
- pkgcraft_
eapi_ ⚠metadata_ keys - Return the array of metadata keys for an Eapi.
- pkgcraft_
eapi_ ⚠parse - Determine if a string is a valid EAPI.
- pkgcraft_
eapis ⚠ - Get all known EAPIS.
- pkgcraft_
eapis_ ⚠official - Get all official EAPIS.
- pkgcraft_
eapis_ ⚠range - Convert EAPI range into an array of Eapi objects.