Functions
- Return an EAPI’s identifier.
- Compare two Eapi objects chronologically returning -1, 0, or 1 if the first is less than, equal to, or greater than the second, respectively.
- Return the array of dependency keys for an Eapi.
- Get an EAPI from its identifier.
- Check if an EAPI has a feature.
- Return the hash value for an Eapi.
- Return the array of metadata keys for an Eapi.
- Determine if a string is a valid EAPI.
- Get all known EAPIS.
- Get all official EAPIS.
- Convert EAPI range into an array of Eapi objects.