Modules
Enums
Functions
- pkgcraft_
pkg_ ⚠cmp - Compare two packages returning -1, 0, or 1 if the first package is less than, equal to, or greater than the second package, respectively.
- pkgcraft_
pkg_ ⚠cpv - Return a package’s CPV.
- pkgcraft_
pkg_ ⚠eapi - Return a package’s EAPI.
- pkgcraft_
pkg_ ⚠format - Return a package’s format.
- pkgcraft_
pkg_ ⚠free - Free an package.
- pkgcraft_
pkg_ ⚠hash - Return the hash value for a package.
- pkgcraft_
pkg_ ⚠intersects_ cpn - Determine if a package intersects with a Cpn.
- pkgcraft_
pkg_ ⚠intersects_ cpv - Determine if a package intersects with a Cpv.
- pkgcraft_
pkg_ ⚠intersects_ dep - Determine if a package intersects with a package dependency.
- pkgcraft_
pkg_ ⚠repo - Return a package’s repo.
- pkgcraft_
pkg_ ⚠restrict - Return the restriction for a package.
- pkgcraft_
pkg_ ⚠restrict_ matches - Determine if a restriction matches a package.
- pkgcraft_
pkg_ ⚠str - Return the string for a package.
- pkgcraft_
pkg_ ⚠version - Return a package’s version.