Functions
- pkgcraft_
restrict_ ⚠and - Create a new restriction combining two restrictions via logical AND.
- pkgcraft_
restrict_ ⚠eq - Determine if two restrictions are equal.
- pkgcraft_
restrict_ ⚠free - Free a restriction.
- pkgcraft_
restrict_ ⚠hash - Return the hash value for a restriction.
- pkgcraft_
restrict_ ⚠not - Create a new restriction inverting a restriction via logical NOT.
- pkgcraft_
restrict_ ⚠or - Create a new restriction combining two restrictions via logical OR.
- pkgcraft_
restrict_ ⚠parse_ dep - Parse a dependency restriction.
- pkgcraft_
restrict_ ⚠parse_ pkg - Parse a package query restriction.
- pkgcraft_
restrict_ ⚠xor - Create a new restriction combining two restrictions via logical XOR.