Functions
- Create a new restriction combining two restrictions via logical AND.
- Determine if two restrictions are equal.
- Free a restriction.
- Return the hash value for a restriction.
- Create a new restriction inverting a restriction via logical NOT.
- Create a new restriction combining two restrictions via logical OR.
- Parse a dependency restriction.
- Parse a package query restriction.
- Create a new restriction combining two restrictions via logical XOR.